@@ -1,4 +1,4 @@
-/* $EPIC: dcc.c,v 1.91 2004/02/20 23:40:22 jnelson Exp $ */
+/* $EPIC: dcc.c,v 1.94 2008/03/17 03:42:46 jnelson Exp $ */
 /*
  * dcc.c: Things dealing client to client connections. 
  *
@@ -48,7 +48,7 @@
 #include "status.h"
 #include "vars.h"
 #include "window.h"
-#include "term.h"
+#include "termx.h"
 #include "notice.h"
 
 #if 0
@@ -1000,7 +1000,7 @@ static void	dcc_send_booster_ctcp (DCC_list *dcc)
 		send_ctcp(CTCP_PRIVMSG, dcc->user, CTCP_DCC,
 			 "%s %s %s %s %ld",
 			 type, url_name, p_host, p_port,
-			 dcc->filesize);
+			 (long)dcc->filesize);
 
 		/*
 		 * Tell the user we sent out the request
@@ -1111,7 +1111,7 @@ const	char 		*text_display, 	/* What to tell the user we sent */
 
 	if (dcc->flags & DCC_QUOTED)
 	{
-		int	len = strlen(text);
+		size_t	len = strlen(text);
 		text = dequote_it(text, &len);
 		writeval = write(dcc->socket, text, len);
 		new_free(&text);
