@@ -1,4 +1,4 @@
-/* $EPIC: irc.c,v 1.768 2008/03/29 04:49:23 jnelson Exp $ */
+/* $EPIC: irc.c,v 1.770 2009/09/05 03:31:22 jnelson Exp $ */
 /*
  * ircII: a new irc client.  I like it.  I hope you will too!
  *
@@ -40,19 +40,19 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC4-2.10";
-const char useful_info[] = "epic4 2 10 0";
+const char irc_version[] = "EPIC4-2.10.1";
+const char useful_info[] = "epic4 2 10 1";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "20080329";
+const char internal_version[] = "20080904";
 
 /*
  * In theory, this number is incremented for every commit.
  */
-const unsigned long	commit_id = 769;
+const unsigned long	commit_id = 771;
 
 /*
  * As a way to poke fun at the current rage of naming releases after
@@ -60,7 +60,7 @@ const unsigned long	commit_id = 769;
  * reality, I have decided to start doing that with EPIC.  These names
  * are intentionally and maliciously silly.  Complaints will be ignored.
  */
-const char ridiculous_version_name[] = "Ineluctable";
+const char ridiculous_version_name[] = "Persiflage";
 
 #define __need_putchar_x__
 #include "status.h"
@@ -1155,7 +1155,7 @@ int 	main (int argc, char *argv[])
 	/* make sure we don't start with spurious signals events firing */
 	memset(&signals_caught, 0, NSIG * sizeof(int));
 	/* hook all signals! */
-	hook_all_signals();
+	init_signals();
 	/* we *might* want to check for SIG_ERR from the above function.
 	 * i leave it to hop to decide what to do on SIG_ERR. -pegasus 
 	 */
