@@ -1,4 +1,4 @@
-/* $EPIC: server.c,v 1.111 2004/08/07 19:54:55 jnelson Exp $ */
+/* $EPIC: server.c,v 1.114 2006/06/17 04:11:18 jnelson Exp $ */
 /*
  * server.c:  Things dealing with that wacky program we call ircd.
  *
@@ -2172,7 +2172,8 @@ int	get_server_port (int refnum)
 	if (!(s = get_server(refnum)))
 		return 0;
 
-	if (!inet_ntostr((SA *)&s->remote_sockname, NULL, 0, p_port, 12, 0))
+	if (is_server_open(refnum))
+	    if (!inet_ntostr((SA *)&s->remote_sockname, NULL, 0, p_port, 12, 0))
 		return atol(p_port);
 
 	return s->port;
@@ -2186,7 +2187,8 @@ int	get_server_local_port (int refnum)
 	if (!(s = get_server(refnum)))
 		return 0;
 
-	if (!inet_ntostr((SA *)&s->remote_sockname, NULL, 0, p_port, 12, 0))
+	if (is_server_open(refnum))
+	    if (!inet_ntostr((SA *)&s->local_sockname, NULL, 0, p_port, 12, 0))
 		return atol(p_port);
 
 	return 0;
@@ -2323,14 +2325,18 @@ void	change_server_nickname (int refnum, const char *nick)
 	{
 	    n = LOCAL_COPY(nick);
 
+	    /* If changing to our Unique ID, the default nickname is 0 */
 	    id = get_server_unique_id(refnum);
-            if ((id && my_stricmp(n, id)) && strcmp(n, "0"))
-            {
+	    if (id && !my_stricmp(nick, id))
+		malloc_strcpy(&s->d_nickname, zero);
+	    else
+	    {
                 if (!(n = check_nickname(n, 1)))
 			reset_nickname(refnum);
+		else
+			malloc_strcpy(&s->d_nickname, n);
 	    }
 
-	    malloc_strcpy(&s->d_nickname, n);
 	    malloc_strcpy(&s->s_nickname, n);
 	}
 
@@ -2351,15 +2357,23 @@ const char *	get_pending_nickname (int refnum)
 void	accept_server_nickname (int refnum, const char *nick)
 {
 	Server *s;
+	const char *id;
 
 	if (!(s = get_server(refnum)))
 		return;
 
+	/* We always accept whatever the server says our new nick is */
 	malloc_strcpy(&s->nickname, nick);
-	malloc_strcpy(&s->d_nickname, nick);
 	new_free(&s->s_nickname);
 	s->fudge_factor = 0;
 
+	/* Change our default nickname to our new nick, or 0 for unique id's */
+	id = get_server_unique_id(refnum);
+	if (id && !my_stricmp(nick, id))
+		malloc_strcpy(&s->d_nickname, zero);
+	else
+		malloc_strcpy(&s->d_nickname, nick);
+
 	if (refnum == primary_server)
 		strlcpy(nickname, nick, sizeof nickname);
 
@@ -2633,7 +2647,6 @@ IACCESSOR(v, line_length)
 IACCESSOR(v, max_cached_chan_size)
 SACCESSOR(chan, invite_channel, NULL)
 SACCESSOR(nick, last_notify_nick, NULL)
-SACCESSOR(id, unique_id, NULL)
 SACCESSOR(nick, joined_nick, NULL)
 SACCESSOR(nick, public_nick, NULL)
 SACCESSOR(nick, recv_nick, NULL)
@@ -2645,6 +2658,21 @@ SACCESSOR(message, quit_message, "get_server_quit_message")
 SACCESSOR(cookie, cookie, NULL)
 SACCESSOR(ver, version_string, NULL)
 
+GET_SATTRIBUTE(unique_id, NULL)
+void    set_server_unique_id (int servref, const char * id)
+{
+	Server *s;
+
+	if (!(s = get_server(servref)))
+		return;
+
+	malloc_strcpy(&s->unique_id , id);
+	if (id && s->d_nickname && !my_stricmp(id, s->d_nickname))
+		malloc_strcpy(&s->d_nickname, zero);
+}
+
+
+
 GET_IATTRIBUTE(operator)
 void	set_server_operator (int refnum, int flag)
 {
@@ -3015,6 +3043,9 @@ char 	*serverctl 	(char *input)
 		} else if (!my_strnicmp(listc, "PORT", len)) {
 			num = get_server_port(refnum);
 			RETURN_INT(num);
+		} else if (!my_strnicmp(listc, "LOCALPORT", len)) {
+			num = get_server_local_port(refnum);
+			RETURN_INT(num);
 		} else if (!my_strnicmp(listc, "QUIT_MESSAGE", len)) {
 			ret = get_server_quit_message(refnum);
 			RETURN_STR(ret);
